/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2010 Martin Rexa
 */

package cz.xelfi.quoridor.statistics.resources;

import cz.xelfi.quoridor.IllegalPositionException;
import cz.xelfi.quoridor.webidor.Game;
import cz.xelfi.quoridor.webidor.GameId;
import cz.xelfi.quoridor.statistics.OpeningTree;
import cz.xelfi.quoridor.statistics.OpeningTreeNode;
import cz.xelfi.quoridor.statistics.OpeningNodeView;
import cz.xelfi.quoridor.webidor.GameStatus;
import java.util.List;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.DefaultValue;
import javax.ws.rs.core.MediaType;

/**
 *
 * @author Martin Rexa
 */
public class Openings {
    OpeningTree tree;

    public Openings(){
        tree = new OpeningTree();
    }

    public void processGame(Game game) {
        try{
            tree.processGame(game);
        }catch (IllegalPositionException e){
            e.printStackTrace();
        }
    }

    @GET
    @Path("{nodeId}")
    @Produces({ MediaType.APPLICATION_JSON, MediaType.TEXT_XML })
    public OpeningNodeView getNode(@QueryParam("loginID") @DefaultValue("") String loginId,
                         @PathParam("nodeId") String nodeId){
        OpeningTreeNode node = tree.getNode(nodeId);
        if(node == null)
            node = tree.getRoot();
        return node.getView(loginId);
    }

    @GET
    @Path("{nodeId}.check")
    @Produces({ MediaType.TEXT_PLAIN })
    public String checkNode(@QueryParam("loginID") @DefaultValue("") String loginId,
                         @PathParam("nodeId") String nodeId){
        OpeningTreeNode node = tree.getNode(nodeId);
        if(node == null)
            return "";
        if(node.getView(loginId).isEmpty())
            return "";
        else
            return nodeId;
    }

    @GET
    @Path("{nodeId}/{status}")
    @Produces({MediaType.APPLICATION_JSON, MediaType.TEXT_XML })
    public List<GameId> listGames(
        @DefaultValue("") @QueryParam("loginID") String loginId,
        @PathParam("nodeId") String nodeId,
        @DefaultValue("") @PathParam("status") String status
    ) {
        OpeningTreeNode node = tree.getNode(nodeId);
        if(node == null)
            return null;
        if("white".equals(status))
            return node.filterGames(loginId, GameStatus.whiteWon);
        else if("black".equals(status))
            return node.filterGames(loginId, GameStatus.blackWon);
        else
            return null;
    }
}
